pub enum SwapQuote {
ExactIn(ExactInSwapQuote),
ExactOut(ExactOutSwapQuote),
}Expand description
Represents the quote for a swap operation.
This enum contains the details of the swap quote based on the type of swap.
Variants
ExactIn(ExactInSwapQuote)
The quote for a swap with a specified input token amount.
ExactOut(ExactOutSwapQuote)
The quote for a swap with a specified output token amount.